/*--------------------------------------------------------------------------

  FILE: dtol.cpp

  PURPOSE: Open Layers data acquisition C++ example, shows single value 
	ADC operation. The C++ file implements the methods declared in dtol.h.
	The methods call the functions of the DT DataAcquisition SDK (beginning
	with olDa.... For urther information please take a look at the 
	documentations in ..\Documentation

****************************************************************************/

//header from the C++ library we need to output the error code
#include <iostream>

//header from the DT DataAcq SDK.
#include "olerrors.h"

//header of this project
#include "dtol.h"

//checks the error code returned by the DT SDK functions.
void showError(ECODE e);

Dtol::Dtol(char* name)
{
	showError(olDaInitialize(name, &hdrvr));
}


Dtol::~Dtol()
{	
	showError(olDaReleaseDASS(hdass));
	showError(olDaTerminate(hdrvr));	
}

void Dtol::setAnalogInputSubsystem()
{	
	showError(olDaGetDASS(hdrvr, OLSS_AD, 0, &hdass));
	showError(olDaSetDataFlow(hdass, OL_DF_SINGLEVALUE));
	showError(olDaConfig(hdass));
}


long Dtol::getValue()
{
	long value;	

	showError(olDaGetSingleValue(hdass, &value, 0, 1.0));

	return value;
}

double Dtol::getVolt(long value)
{
	double volts, minRangeVolts, maxRangeVolts;
	unsigned int bitResolution, encoding;

	showError(olDaGetRange(hdass, &maxRangeVolts, &minRangeVolts));
	showError(olDaGetEncoding(hdass, &encoding));
	showError(olDaGetResolution(hdass, &bitResolution));
	showError(olDaCodeToVolts(minRangeVolts, maxRangeVolts, 1.0, bitResolution, encoding, value, &volts));

	return volts;
}

void showError(ECODE e)
{
	if(e != OLNOERROR)
	{
		char temp[80];
		olDaGetErrorString(e, temp, 80);
		std::cout << "The error " << temp << " occured.\nApplication is stopped.\n" << std::endl;
		exit(0);
	}
}

