/*--------------------------------------------------------------------------

  FILE: main.cpp

  PURPOSE: Open Layers data acquisition C++ example, shows single value 
	ADC operation. The C++ file implements the main()-method which creates
	an Dtol object. By creating further Dtol objects with different board
	names the program can access more than one DT device. e.g.

		Dtol dt9812 = Dtol("DT9812-10V(00)");
		dt9812.setAnalogInputSubsystem();
		long value = dt9812.getValue();
		double volt = dt9812.getVolt(value);
	

****************************************************************************/

#include <iostream>

#include "dtol.h"

using namespace std;

void printStart();

void main()
{
	printStart();

	char name[20];	
	cout << "Please enter the name of the DT device (max. 20 chars): ";
	cin.width(20);
	cin >> name;
	Dtol d = Dtol(name);
	d.setAnalogInputSubsystem();
	
	cout << "Press v to get a new value or q to quit: ";
	char ch;
	cin >> ch;
	while(ch != 'q')
	{
		if(ch == 'v')
		{
			cout << d.getVolt(d.getValue()) << endl;
			cout << "\nPress v to get a new value or q to quit: ";
		}

		cin >> ch;
	}	
	cout << "\n***************************************************************\n\n";
}

void printStart()
{
	cout << "***************************************************************\n"; 
	cout << "*                                                             *\n"; 
	cout << "*  Open Layers data acquisition C++ example, showing single   *\n"; 
	cout << "*  value ADC operation on channel 0, gain 1.0                 *\n";
	cout << "*                                                             *\n"; 
	cout << "***************************************************************\n"; 
	cout << endl;
}